summaryrefslogtreecommitdiff
path: root/desktop
diff options
context:
space:
mode:
Diffstat (limited to 'desktop')
-rw-r--r--desktop/options.h5
-rw-r--r--desktop/treeview.c6
2 files changed, 5 insertions, 6 deletions
diff --git a/desktop/treeview.c b/desktop/treeview.c
index 5e4ceed12..fa7fea02d 100644
--- a/desktop/treeview.c
+++ b/desktop/treeview.c
@@ -3962,11 +3962,7 @@ nserror treeview_init(void)
LOG("Initialising treeview module");
- /* TODO: Should we add an extra `treeview_font_size` option for
- * treeviews instead of reusing the html rendering default
- * font size?
- */
- font_pt_size = nsoption_int(font_size);
+ font_pt_size = nsoption_int(treeview_font_size);
if (font_pt_size <= 0) {
font_pt_size = 11 * 10;
}
diff --git a/desktop/options.h b/desktop/options.h
index 2f3688750..437d104e9 100644
--- a/desktop/options.h
+++ b/desktop/options.h
@@ -59,7 +59,10 @@ NSOPTION_STRING(http_proxy_auth_pass, NULL)
/** Proxy omission list */
NSOPTION_STRING(http_proxy_noproxy, "localhost")
-/** Default font size / 0.1pt. */
+/** Default treeview font size (unit: 0.1pt) */
+NSOPTION_INTEGER(treeview_font_size, 110)
+
+/** Default font size (unit: 0.1pt) */
NSOPTION_INTEGER(font_size, 128)
/** Minimum font size. */